@@ -1,21 +1,21 @@
 #############################################################################
-#    Copyright (c) 2010-2018 Rune Haubo Bojesen Christensen
-#
-#    This file is part of the ordinal package for R (*ordinal*)
-#
-#    *ordinal* is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 2 of the License, or
-#    (at your option) any later version.
-#
-#    *ordinal* is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    A copy of the GNU General Public License is available at
-#    <https://www.r-project.org/Licenses/> and/or
-#    <http://www.gnu.org/licenses/>.
+##    Copyright (c) 2010-2022 Rune Haubo Bojesen Christensen
+##
+##    This file is part of the ordinal package for R (*ordinal*)
+##
+##    *ordinal* is free software: you can redistribute it and/or modify
+##    it under the terms of the GNU General Public License as published by
+##    the Free Software Foundation, either version 2 of the License, or
+##    (at your option) any later version.
+##
+##    *ordinal* is distributed in the hope that it will be useful,
+##    but WITHOUT ANY WARRANTY; without even the implied warranty of
+##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+##    GNU General Public License for more details.
+##
+##    A copy of the GNU General Public License is available at
+##    <https://www.r-project.org/Licenses/> and/or
+##    <http://www.gnu.org/licenses/>.
 #############################################################################
 ## This file contains:
 ## Various utility functions.
@@ -329,7 +329,7 @@ getB <- function(y, NOM=NULL, X=NULL, offset=NULL, tJac=NULL) {
     B2 <- B2 %*% tJac
   }
   ## update B1 and B2 with nominal effects:
-  if(NCOL(NOM) > 1) { ## !is.null(NOM) && ncol(NOM) > 1) {
+  if(!is.null(NOM) && ncol(NOM) > 1) {
     ## if !is.null(NOM) and NOM is more than an intercept:
     LL1 <- lapply(1:ncol(NOM), function(x) B1 * NOM[,x])
     B1 <- do.call(cbind, LL1)
@@ -337,8 +337,8 @@ getB <- function(y, NOM=NULL, X=NULL, offset=NULL, tJac=NULL) {
     B2 <- do.call(cbind, LL2)
   }
   ## update B1 and B2 with location effects (X):
-  nbeta <- NCOL(X) - 1
-  if(NCOL(X) > 1) {
+  nbeta <- ncol(X) - 1
+  if(ncol(X) > 1) {
     B1 <- cbind(B1, -X[, -1, drop = FALSE])
     B2 <- cbind(B2, -X[, -1, drop = FALSE])
   }
@@ -349,11 +349,12 @@ getB <- function(y, NOM=NULL, X=NULL, offset=NULL, tJac=NULL) {
 
 Deparse <-
   function(expr, width.cutoff = 500L, backtick = mode(expr) %in%
-           c("call", "expression", "(", "function"),
+             c("call", "expression", "(", "function"),
            control = c("keepInteger", "showAttributes", "keepNA"),
            nlines = -1L)
-  deparse(expr=expr, width.cutoff= width.cutoff, backtick=backtick,
-          control=control, nlines=nlines)
+    paste(deparse(expr=expr, width.cutoff= width.cutoff, 
+                  backtick=backtick,
+                  control=control, nlines=nlines), collapse = " ")
 
 getContrasts <- function(terms, contrasts) {
     if(is.null(contrasts)) return(NULL)
